@@ -8,13 +8,13 @@
 from . import literals
 from . import api
 from . import step
-from . import journey
+from . import guide
 from . import enums
 
 __all__ = [
     'api',
     'step',
-    'journey',
+    'guide',
     'literals',
     'enums'
 ]
