@@ -10,8 +10,8 @@ Automation
 This class contains the helper methods extensions used to register, deploy, and test the created tasks. Additional helper
 functions for retrieving details of existing tasks on the Switch Automation Platform are also included in this module.
 """
-from .JourneyDefinitionTask import JourneyDefinitionTask
-from .JourneyRetrySupportTask import JourneyRetrySupportTask
-from .JourneyStepDefinitionTask import JourneyStepDefinitionTask
+from .GuideDefinitionTask import GuideDefinitionTask
+from .GuideRetrySupportTask import GuideRetrySupportTask
+from .GuideStepDefinitionTask import GuideStepDefinitionTask
 
-__all__ = ['JourneyDefinitionTask', 'JourneyRetrySupportTask', 'JourneyStepDefinitionTask']
+__all__ = ['GuideDefinitionTask', 'GuideRetrySupportTask', 'GuideStepDefinitionTask']
